@@ -25,7 +25,7 @@ Version 0.06
 
 =cut
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 
 =head1 SYNOPSIS
@@ -582,13 +582,8 @@ sub write_annovar{
     print "wait\n\n";
 
 #    #Annotate annovar input
-    foreach my $file (@{$self->vcfs}){
-        $self->file($file);
-        my $tname = basename($self->file);
-        $tname =~ s/\.vcf$|\.vcf\.gz$//;
-        $self->fname($tname);
-        $self->table_annovar;
-    }
+
+    $self->iter_vcfs('table_annovar');
 
     print "## Wait for all table commands to complete\n";
     print "wait\n\n";
@@ -597,6 +592,28 @@ sub write_annovar{
 #    #This is only relevant for putting it back into vcfs
 
     return unless $self->annotate_vcf;
+
+    $self->iter_vcfs('gen_descr');
+    
+    print "## Wait for file copying bgzip and tabix to finish...\n";
+    print "wait\n\n";
+
+    $self->iter_vcfs('gen_annot');
+
+    print "## Wait for all vcf-annotate commands to complete\n";
+    print "wait\n\n";
+
+    $self->iter_vcfs('merge_vcfs');
+
+}
+
+=head2 iter_vcfs
+Iterate over the vcfs with some changes for lookups
+=cut
+sub iter_vcfs{
+#    my $self = shift;
+    my($self, $fun) = @_;
+
     foreach my $file (@{$self->vcfs}){
         $self->file($file);
         my $tname = basename($self->file);
@@ -604,7 +621,7 @@ sub write_annovar{
         $self->fname($tname);
 #        $self->fname(basename($self->file));
         #Make this a parameter of the script
-        $self->vcf_annotate;
+        $self->$fun;
     }
 
 }
@@ -705,6 +722,9 @@ sub vcf_annotate{
     my($self) = @_;
 
     $self->gen_descr;
+    $self->gen_annot;
+
+
     $self->merge_vcfs;
 }
 
@@ -752,8 +772,12 @@ sub gen_descr{
         print "&& tabix -s 1 -b 2 -e 3 ".$self->outdir."/vcf-annotate_interim/".$self->fname.".sorted.annovar.$sample.hg19_multianno.txt.gz \n\n";
     }
 
-    print "## Wait for file copying bgzip and tabix to finish...\n";
-    print "wait\n\n";
+}
+
+=head2 gen_annot
+=cut
+sub gen_annot {
+    my $self = shift;
 
     print "##Reannotate VCF files\n\n";
     foreach my $sample (@{$self->samples->{$self->file}}){
@@ -791,12 +815,8 @@ EOF
 
         $self->gen_cols($sample);
     }
-
-    print "## Wait for all vcf-annotate commands to complete\n";
-    print "wait\n\n";
-
+    
 }
-
 =head2 gen_cols
 
 Generate the -c portion of the vcf-annotate command
